==> geotrellis-layer_2.12-3.2.0-sources.jar: geotrellis/layer/buffer/CollectionBufferTilesMethods.scala <==
/*
 * Copyright 2016 Azavea
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package geotrellis.layer.buffer

import geotrellis.raster._
import geotrellis.raster.buffer._
import geotrellis.raster.crop._
import geotrellis.raster.stitch._
import geotrellis.layer.{SpatialComponent, TileBounds}
import geotrellis.util.MethodExtensions

class CollectionBufferTilesMethods[
  K: SpatialComponent,
  V <: CellGrid[Int]: Stitcher: (* => CropMethods[V])
](val self: Seq[(K, V)]) extends MethodExtensions[Seq[(K, V)]] {
  def bufferTiles(bufferSize: Int): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, bufferSize)

  def bufferTiles(bufferSize: Int, layerBounds: TileBounds): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, bufferSize, layerBounds)

  def bufferTiles(bufferSizesPerKey: Seq[(K, BufferSizes)]): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, bufferSizesPerKey)

  def bufferTiles(getBufferSizes: K => BufferSizes): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, getBufferSizes)
}

==> geotrellis-layer_2.12-3.6.3-sources.jar: geotrellis/layer/buffer/CollectionBufferTilesMethods.scala <==
/*
 * Copyright 2016 Azavea
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package geotrellis.layer.buffer

import geotrellis.raster._
import geotrellis.raster.buffer._
import geotrellis.raster.crop._
import geotrellis.raster.stitch._
import geotrellis.layer.{SpatialComponent, TileBounds}
import geotrellis.util.MethodExtensions

class CollectionBufferTilesMethods[
  K: SpatialComponent,
  V <: CellGrid[Int]: Stitcher: * => CropMethods[V]
](val self: Seq[(K, V)]) extends MethodExtensions[Seq[(K, V)]] {
  def bufferTiles(bufferSize: Int): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, bufferSize)

  def bufferTiles(bufferSize: Int, layerBounds: TileBounds): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, bufferSize, layerBounds)

  def bufferTiles(bufferSizesPerKey: Seq[(K, BufferSizes)]): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, bufferSizesPerKey)

  def bufferTiles(getBufferSizes: K => BufferSizes): Seq[(K, BufferedTile[V])] =
    BufferTiles(self, getBufferSizes)
}
